@@ -21,16 +21,35 @@ import six
 @six.add_metaclass(abc.ABCMeta)
 class AmphoraLoadBalancerDriver(object):
 
+    @abc.abstractmethod
+    def update_amphora_listeners(self, listeners, amphora_id, timeout_dict):
+        """Update the amphora with a new configuration.
+
+        :param listeners: List of listeners to update.
+        :type listener: list
+        :param amphora_id: The ID of the amphora to update
+        :type amphora_id: string
+        :param timeout_dict: Dictionary of timeout values for calls to the
+                             amphora. May contain: req_conn_timeout,
+                             req_read_timeout, conn_max_retries,
+                             conn_retry_interval
+        :returns: None
+
+        Builds a new configuration, pushes it to the amphora, and reloads
+        the listener on one amphora.
+        """
+        pass
+
     @abc.abstractmethod
     def update(self, listener, vip):
         """Update the amphora with a new configuration.
 
         :param listener: listener object,
-        need to use its protocol_port property
+                         need to use its protocol_port property
         :type listener: object
         :param vip: vip object, need to use its ip_address property
         :type vip: object
-        :returns: return a value list (listener, vip, status flag--update)
+        :returns: None
 
         At this moment, we just build the basic structure for testing, will
         add more function along with the development.
@@ -42,7 +61,7 @@ class AmphoraLoadBalancerDriver(object):
         """Stop the listener on the vip.
 
         :param listener: listener object,
-        need to use its protocol_port property
+                         need to use its protocol_port property
         :type listener: object
         :param vip: vip object, need to use its ip_address property
         :type vip: object
@@ -54,14 +73,16 @@ class AmphoraLoadBalancerDriver(object):
         pass
 
     @abc.abstractmethod
-    def start(self, listener, vip):
+    def start(self, listener, vip, amphora):
         """Start the listener on the vip.
 
         :param listener: listener object,
-        need to use its protocol_port property
+                         need to use its protocol_port property
         :type listener: object
-        :param vip : vip object, need to use its ip_address property
+        :param vip: vip object, need to use its ip_address property
         :type vip: object
+        :param amphora: Amphora to start. If None, start on all amphora
+        :type amphora: object
         :returns: return a value list (listener, vip, status flag--enable)
 
         At this moment, we just build the basic structure for testing, will
@@ -74,7 +95,7 @@ class AmphoraLoadBalancerDriver(object):
         """Delete the listener on the vip.
 
         :param listener: listener object,
-        need to use its protocol_port property
+                         need to use its protocol_port property
         :type listener: object
         :param vip: vip object, need to use its ip_address property
         :type vip: object
@@ -109,7 +130,7 @@ class AmphoraLoadBalancerDriver(object):
         :param amphora: amphora object, need to use its id property
         :type amphora: object
         :returns: return a value list (amphora.id, status flag--'ge
-        t_diagnostics')
+                  t_diagnostics')
 
         At this moment, we just build the basic structure for testing, will
         add more function along with the development, eventually, we want it
@@ -198,6 +219,16 @@ class AmphoraLoadBalancerDriver(object):
         """
         pass
 
+    def update_agent_config(self, amphora, agent_config):
+        """Upload and update the amphora agent configuration.
+
+        :param amphora: amphora object, needs id and network ip(s)
+        :type amphora: object
+        :param agent_config: The new amphora agent configuration file.
+        :type agent_config: string
+        """
+        pass
+
 
 @six.add_metaclass(abc.ABCMeta)
 class HealthMixin(object):
@@ -283,3 +314,11 @@ class VRRPDriverMixin(object):
         :param loadbalancer: loadbalancer object
         """
         pass
+
+    @abc.abstractmethod
+    def get_vrrp_interface(self, amphora):
+        """Get the VRRP interface object for a specific amphora
+
+        :param amphora: amphora object
+        """
+        pass
