@@ -12,16 +12,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from keystonemiddleware import auth_token
+import keystonemiddleware.audit as audit_middleware
 from oslo_config import cfg
+from oslo_log import log as logging
 from oslo_middleware import cors
 from oslo_middleware import request_id
 import pecan
 
 from octavia.api import config as app_config
+from octavia.api.drivers import driver_factory
 from octavia.common import constants
+from octavia.common import exceptions
+from octavia.common import keystone
 from octavia.common import service as octavia_service
 
+LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
+
 
 def get_pecan_config():
     """Returns the pecan config."""
@@ -29,9 +36,18 @@ def get_pecan_config():
     return pecan.configuration.conf_from_file(filename)
 
 
+def _init_drivers():
+    """Initialize provider drivers."""
+    for provider in CONF.api_settings.enabled_provider_drivers:
+        driver_factory.get_driver(provider)
+
+
 def setup_app(pecan_config=None, debug=False, argv=None):
     """Creates and returns a pecan wsgi app."""
     octavia_service.prepare_service(argv)
+    cfg.CONF.log_opt_values(LOG, logging.DEBUG)
+
+    _init_drivers()
 
     if not pecan_config:
         pecan_config = get_pecan_config()
@@ -49,8 +65,23 @@ def setup_app(pecan_config=None, debug=False, argv=None):
 def _wrap_app(app):
     """Wraps wsgi app with additional middlewares."""
     app = request_id.RequestId(app)
-    if cfg.CONF.auth_strategy == constants.KEYSTONE:
-        app = auth_token.AuthProtocol(app, {})
+
+    if CONF.audit.enabled:
+        try:
+            app = audit_middleware.AuditMiddleware(
+                app,
+                audit_map_file=CONF.audit.audit_map_file,
+                ignore_req_list=CONF.audit.ignore_req_list
+            )
+        except (EnvironmentError, OSError,
+                audit_middleware.PycadfAuditApiConfigError) as e:
+            raise exceptions.InputFileError(
+                file_name=CONF.audit.audit_map_file,
+                reason=e
+            )
+
+    if cfg.CONF.api_settings.auth_strategy == constants.KEYSTONE:
+        app = keystone.SkippingAuthProtocol(app, {})
 
     # This should be the last middleware in the list (which results in
     # it being the first in the middleware chain). This is to ensure
@@ -58,7 +89,7 @@ def _wrap_app(app):
     # middleware - are annotated with CORS headers, and thus accessible
     # by the browser.
     app = cors.CORS(app, cfg.CONF)
-    app.set_latent(
+    cors.set_defaults(
         allow_headers=['X-Auth-Token', 'X-Openstack-Request-Id'],
         allow_methods=['GET', 'PUT', 'POST', 'DELETE'],
         expose_headers=['X-Auth-Token', 'X-Openstack-Request-Id']
