@@ -17,8 +17,8 @@ import copy
 import six
 
 from oslo_config import cfg
+from oslo_context import context as oslo_context
 from oslo_log import log as logging
-from oslo_utils import excutils
 from stevedore import driver as stevedore_driver
 
 from octavia.api.drivers import data_models as driver_dm
@@ -87,13 +87,19 @@ def _base_to_provider_dict(current_dict, include_project_id=False):
         del new_dict['project_id']
     if 'tenant_id' in new_dict:
         del new_dict['tenant_id']
+    if 'tags' in new_dict:
+        del new_dict['tags']
+    if 'flavor_id' in new_dict:
+        del new_dict['flavor_id']
+    if 'topology' in new_dict:
+        del new_dict['topology']
     return new_dict
 
 
 # Note: The provider dict returned from this method will have provider
 #       data model objects in it.
-def lb_dict_to_provider_dict(lb_dict, vip=None, db_pools=None,
-                             db_listeners=None, for_delete=False):
+def lb_dict_to_provider_dict(lb_dict, vip=None,
+                             db_pools=None, db_listeners=None):
     new_lb_dict = _base_to_provider_dict(lb_dict, include_project_id=True)
     new_lb_dict['loadbalancer_id'] = new_lb_dict.pop('id')
     if vip:
@@ -107,37 +113,36 @@ def lb_dict_to_provider_dict(lb_dict, vip=None, db_pools=None,
         new_lb_dict['pools'] = db_pools_to_provider_pools(db_pools)
     if db_listeners:
         new_lb_dict['listeners'] = db_listeners_to_provider_listeners(
-            db_listeners, for_delete=for_delete)
+            db_listeners)
     return new_lb_dict
 
 
-def db_loadbalancer_to_provider_loadbalancer(db_loadbalancer,
-                                             for_delete=False):
+def db_loadbalancer_to_provider_loadbalancer(db_loadbalancer):
     new_loadbalancer_dict = lb_dict_to_provider_dict(
         db_loadbalancer.to_dict(recurse=True),
         vip=db_loadbalancer.vip,
         db_pools=db_loadbalancer.pools,
-        db_listeners=db_loadbalancer.listeners, for_delete=for_delete)
+        db_listeners=db_loadbalancer.listeners)
     for unsupported_field in ['server_group_id', 'amphorae',
                               'vrrp_group', 'topology', 'vip']:
-        del new_loadbalancer_dict[unsupported_field]
+        if unsupported_field in new_loadbalancer_dict:
+            del new_loadbalancer_dict[unsupported_field]
     provider_loadbalancer = driver_dm.LoadBalancer.from_dict(
         new_loadbalancer_dict)
     return provider_loadbalancer
 
 
-def db_listeners_to_provider_listeners(db_listeners, for_delete=False):
+def db_listeners_to_provider_listeners(db_listeners):
     provider_listeners = []
     for listener in db_listeners:
-        provider_listener = db_listener_to_provider_listener(
-            listener, for_delete=for_delete)
+        provider_listener = db_listener_to_provider_listener(listener)
         provider_listeners.append(provider_listener)
     return provider_listeners
 
 
-def db_listener_to_provider_listener(db_listener, for_delete=False):
+def db_listener_to_provider_listener(db_listener):
     new_listener_dict = listener_dict_to_provider_dict(
-        db_listener.to_dict(recurse=True), for_delete=for_delete)
+        db_listener.to_dict(recurse=True))
     if ('default_pool' in new_listener_dict and
             new_listener_dict['default_pool']):
         provider_pool = db_pool_to_provider_pool(db_listener.default_pool)
@@ -150,7 +155,16 @@ def db_listener_to_provider_listener(db_listener, for_delete=False):
     return provider_listener
 
 
-def listener_dict_to_provider_dict(listener_dict, for_delete=False):
+def _get_secret_data(cert_manager, project_id, secret_ref):
+    """Get the secret from the certificate manager and upload it to the amp.
+
+    :returns: The secret data.
+    """
+    context = oslo_context.RequestContext(project_id=project_id)
+    return cert_manager.get_secret(context, secret_ref)
+
+
+def listener_dict_to_provider_dict(listener_dict):
     new_listener_dict = _base_to_provider_dict(listener_dict)
     new_listener_dict['listener_id'] = new_listener_dict.pop('id')
     if 'load_balancer_id' in new_listener_dict:
@@ -167,8 +181,15 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
     if 'sni_container_refs' in listener_dict:
         listener_dict['sni_containers'] = listener_dict.pop(
             'sni_container_refs')
+    if 'client_ca_tls_certificate_id' in new_listener_dict:
+        new_listener_dict['client_ca_tls_container_ref'] = (
+            new_listener_dict.pop('client_ca_tls_certificate_id'))
+    if 'client_crl_container_id' in new_listener_dict:
+        new_listener_dict['client_crl_container_ref'] = (
+            new_listener_dict.pop('client_crl_container_id'))
     listener_obj = data_models.Listener(**listener_dict)
-    if listener_obj.tls_certificate_id or listener_obj.sni_containers:
+    if (listener_obj.tls_certificate_id or listener_obj.sni_containers or
+            listener_obj.client_ca_tls_certificate_id):
         SNI_objs = []
         for sni in listener_obj.sni_containers:
             if isinstance(sni, dict):
@@ -186,25 +207,26 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
             name=CONF.certificates.cert_manager,
             invoke_on_load=True,
         ).driver
-        try:
-            cert_dict = cert_parser.load_certificates_data(cert_manager,
-                                                           listener_obj)
-        except Exception as e:
-            with excutils.save_and_reraise_exception() as ctxt:
-                LOG.warning('Unable to retrieve certificate(s) due to %s.',
-                            str(e))
-                if for_delete:
-                    ctxt.reraise = False
-                    cert_dict = {}
-        if 'tls_cert' in cert_dict:
+        cert_dict = cert_parser.load_certificates_data(cert_manager,
+                                                       listener_obj)
+        if 'tls_cert' in cert_dict and cert_dict['tls_cert']:
             new_listener_dict['default_tls_container_data'] = (
                 cert_dict['tls_cert'].to_dict())
-        if 'sni_certs' in cert_dict:
+        if 'sni_certs' in cert_dict and cert_dict['sni_certs']:
             sni_data_list = []
             for sni in cert_dict['sni_certs']:
                 sni_data_list.append(sni.to_dict())
             new_listener_dict['sni_container_data'] = sni_data_list
 
+        if listener_obj.client_ca_tls_certificate_id:
+            cert = _get_secret_data(cert_manager, listener_obj.project_id,
+                                    listener_obj.client_ca_tls_certificate_id)
+            new_listener_dict['client_ca_tls_container_data'] = cert
+        if listener_obj.client_crl_container_id:
+            crl_file = _get_secret_data(cert_manager, listener_obj.project_id,
+                                        listener_obj.client_crl_container_id)
+            new_listener_dict['client_crl_container_data'] = crl_file
+
     # Remove the DB back references
     if 'load_balancer' in new_listener_dict:
         del new_listener_dict['load_balancer']
@@ -259,6 +281,42 @@ def db_pool_to_provider_pool(db_pool):
 def pool_dict_to_provider_dict(pool_dict):
     new_pool_dict = _base_to_provider_dict(pool_dict)
     new_pool_dict['pool_id'] = new_pool_dict.pop('id')
+
+    # Pull the certs out of the certificate manager to pass to the provider
+    if 'tls_certificate_id' in new_pool_dict:
+        new_pool_dict['tls_container_ref'] = new_pool_dict.pop(
+            'tls_certificate_id')
+    if 'ca_tls_certificate_id' in new_pool_dict:
+        new_pool_dict['ca_tls_container_ref'] = new_pool_dict.pop(
+            'ca_tls_certificate_id')
+    if 'crl_container_id' in new_pool_dict:
+        new_pool_dict['crl_container_ref'] = new_pool_dict.pop(
+            'crl_container_id')
+
+    pool_obj = data_models.Pool(**pool_dict)
+    if (pool_obj.tls_certificate_id or pool_obj.ca_tls_certificate_id or
+            pool_obj.crl_container_id):
+        cert_manager = stevedore_driver.DriverManager(
+            namespace='octavia.cert_manager',
+            name=CONF.certificates.cert_manager,
+            invoke_on_load=True,
+        ).driver
+        cert_dict = cert_parser.load_certificates_data(cert_manager,
+                                                       pool_obj)
+        if 'tls_cert' in cert_dict and cert_dict['tls_cert']:
+            new_pool_dict['tls_container_data'] = (
+                cert_dict['tls_cert'].to_dict())
+
+        if pool_obj.ca_tls_certificate_id:
+            cert = _get_secret_data(cert_manager, pool_obj.project_id,
+                                    pool_obj.ca_tls_certificate_id)
+            new_pool_dict['ca_tls_container_data'] = cert
+
+        if pool_obj.crl_container_id:
+            crl_file = _get_secret_data(cert_manager, pool_obj.project_id,
+                                        pool_obj.crl_container_id)
+            new_pool_dict['crl_container_data'] = crl_file
+
     # Remove the DB back references
     if ('session_persistence' in new_pool_dict and
             new_pool_dict['session_persistence']):
