@@ -284,7 +284,7 @@ class AbstractNetworkDriver(object):
         pass
 
     @abc.abstractmethod
-    def get_network_configs(self, load_balancer):
+    def get_network_configs(self, load_balancer, amphora=None):
         """Retrieve network configurations
 
         This method assumes that a dictionary of AmphoraNetworkConfigs keyed
@@ -298,6 +298,7 @@ class AbstractNetworkDriver(object):
         Example return: {<amphora.id>: <AmphoraNetworkConfig>}
 
         :param load_balancer: The load_balancer configuration
+        :param amphora: Optional amphora to only query.
         :return: dict of octavia.network.data_models.AmphoraNetworkConfig
                  keyed off of the amphora id the config is associated with.
         :raises: NotFound, NetworkNotFound, SubnetNotFound, PortNotFound
@@ -319,18 +320,39 @@ class AbstractNetworkDriver(object):
         """
         pass
 
+    @abc.abstractmethod
+    def update_vip_sg(self, load_balancer, vip):
+        """Updates the security group for a VIP
+
+        :param load_balancer: Load Balancer to rpepare the VIP for
+        :param vip: The VIP to plug
+        """
+        pass
+
+    @abc.abstractmethod
+    def plug_aap_port(self, load_balancer, vip, amphora, subnet):
+        """Plugs the AAP port to the amp
+
+        :param load_balancer: Load Balancer to prepare the VIP for
+        :param vip: The VIP to plug
+        :param amphora: The amphora to plug the VIP into
+        :param subnet: The subnet to plug the aap into
+        """
+        pass
+
+    @abc.abstractmethod
+    def unplug_aap_port(self, vip, amphora, subnet):
+        """Unplugs the AAP port to the amp
+
+        :param vip: The VIP to plug
+        :param amphora: The amphora to plug the VIP into
+        :param subnet: The subnet to plug the aap into
+        """
+        pass
+
     @abc.abstractmethod
     def qos_enabled(self):
         """Whether QoS is enabled
 
         :return: Boolean
         """
-
-    @abc.abstractmethod
-    def get_network_ip_availability(self, network):
-        """Retrieves network IP availability.
-
-        :param network: octavia.network.data_models.Network
-        :return: octavia.network.data_models.Network_IP_Availability
-        :raises: NetworkException, NetworkNotFound
-        """
