@@ -14,9 +14,6 @@ function load_conf_hook {
     _DEVSTACK_LOCAL_CONFIG_TAIL+=$'\n'"$(cat $GATE_HOOKS/$hook)"
 }
 
-# Work around a devstack issue:https://review.openstack.org/#/c/435106
-export DEVSTACK_LOCAL_CONFIG+=$'\n'"DEFAULT_IMAGE_NAME=cirros-0.3.5-x86_64-disk"$'\n'
-
 export DEVSTACK_LOCAL_CONFIG+=$'\n'"enable_plugin barbican https://git.openstack.org/openstack/barbican"$'\n'
 
 # Allow testing against diskimage-builder changes with depends-on
@@ -25,11 +22,11 @@ export DEVSTACK_LOCAL_CONFIG+=$'\n'"LIBS_FROM_GIT+=,diskimage-builder"$'\n'
 # Sort out our gate args
 . $(dirname "$0")/decode_args.sh
 
-# Note: The check for OVH instances is temporary until they resolve the
-# KVM failures as logged here:
+# Note: The check for OVH and limestone instances is temporary until they
+# resolve the KVM failures as logged here:
 # https://bugzilla.kernel.org/show_bug.cgi?id=192521
 # However, this may be resolved at OVH before the kernel bug is resolved.
-if $(egrep --quiet '(vmx|svm)' /proc/cpuinfo) && [[ ! $(hostname) =~ "ovh" ]]; then
+if $(egrep --quiet '(vmx|svm)' /proc/cpuinfo) && [[ ( ! $(hostname) =~ "ovh" && ! $(hostname) =~ "limestone" ) ]]; then
     export DEVSTACK_GATE_LIBVIRT_TYPE=kvm
 fi
 
